#include "testlib.h"
#include <map>
#include <set>
#include <unordered_set>
#include <queue>
#include <iostream>

using namespace std;

typedef vector<unordered_set<int>> graph;

struct state {
    int v;
    int start;
    int mask;

    bool is_visited(int v) {
        return static_cast<bool>((mask >> v) & 1);
    }

    bool operator<(const state &other) const {
        if (v != other.v) return v < other.v;
        if (start != other.start) return start < other.start;
        return mask < other.mask;
    }

    bool operator==(const state &other) const {
        return (v == other.v && start == other.start && mask == other.mask);
    }
};

struct state_hash {
    size_t operator()(const state &s) const {
        return s.v ^ s.start ^ s.mask;
    }
};

int n, m;

bool is_trouble(graph &g) {
    queue<state> q;
    unordered_set<state, state_hash> used;
    for (int v = 1; v <= n; ++v) {
        q.push({v, v, (1 << v)});
    }
    while (!q.empty()) {
        auto cur = q.front();
        q.pop();

        bool found = false;
        for (int to : g[cur.v]) {
            if (!cur.is_visited(to)) {
                state next = {to, cur.start, cur.mask | (1 << to)};
                if (used.find(next) == used.end()) {
                    q.push(next);
                    used.insert(next);
                }

                found = true;
            }
        }

        if (!found) {
            bool all_visited = true;
            for (int v = 1; v <= n; ++v) {
                if (!cur.is_visited(v)) {
                    all_visited = false;
                    break;
                }
            }

            if (all_visited) {
                if (g[cur.v].find(cur.start) == g[cur.v].end()) {
                    return true;
                }
            } else {
                return true;
            }
        }
    }
    return false;
}


bool readAns(InStream &stream) {
    graph g(static_cast<unsigned long>(n + 1));

    string s = stream.readString();
    if (s == "Impossible") {
        stream.readEoln();
        stream.readEof();
        return false;
    }
    if (s != "Possible") {
        stream.quitf(_pe, "incorrect answer format");
    }

    set<pair<int, int>> used;
    for (int i = 0; i < m; i++) {
        int u = stream.readInt(1, n);
        int v = stream.readInt(1, n);
        if (u == v) {
            stream.quitf(_pe, "edges between the same vertex are not allowed");
        }
        if (used.find({v, u}) != used.end()) {
            stream.quitf(_pe, "double edges are not allowed");
        }
        g[u].insert(v);
        g[v].insert(u);
        used.emplace(u, v);
        used.emplace(v, u);
    }
    stream.readEoln();
    stream.readEof();

    if (is_trouble(g)) {
        stream.quitf(_wa, "incorrect graph");
    }
    return true;
}

int main(int argc, char *argv[]) {
    registerTestlibCmd(argc, argv);
    n = inf.readInt();
    m = inf.readInt();

    bool expected = readAns(ans);
    bool actual = readAns(ouf);
    if (expected && !actual)
        quitf(_wa, "jury has the answer but participant does not\n");
    else if (expected == actual)
        quitf(_ok, "correct");
    else
        quitf(_fail, ":( participant has found the answer but jury did not\n");
}
