#include "testlib.h"
#include <map>
#include <vector>
#include <iostream>

using namespace std;

typedef vector<vector<int>> graph;

int n, m;

bool is_cycle(graph &g) {
    auto n = static_cast<int>(g.size() - 1);
    for (int i = 1; i <= n; ++i) {
        if (g[i].size() != 2) return false;
    }

    vector<bool> visited(n + 1);
    int v = 1;
    for (int i = 0; i < n; ++i) {
        visited[v] = true;
        for (int to : g[v]) {
            if (!visited[to]) {
                v = to;
                break;
            }
        }
    }

    for (int i = 1; i <= n; ++i) {
        if (!visited[i]) return false;
    }
    return true;
}

bool is_complete(graph &g) {
    auto n = static_cast<int>(g.size() - 1);
    for (int i = 1; i <= n; ++i) {
        if (g[i].size() != n - 1) return false;
    }
    return true;
}

bool _dfs(graph &g, vector<int> &color, int v) {
    for (int to : g[v]) {
        if (color[to] == color[v]) {
            return false;
        }
        bool is_next = color[to] == 0;
        color[to] = 3 - color[v];

        if (is_next && !_dfs(g, color, to)) return false;
    }
    return true;
}

bool is_cm_bipartite(graph &g) {
    auto n = static_cast<int>(g.size() - 1);
    if (n % 2 == 1) return false;

    for (int i = 1; i <= n; ++i) {
        if (g[i].size() != n / 2) return false;
    }

    vector<int> color(n + 1);
    color[1] = 1;
    bool ok = _dfs(g, color, 1);
    return ok;
}

bool readAns(InStream &stream) {
    graph g(static_cast<unsigned long>(n + 1));

    string s = stream.readString();
    if (s == "Impossible") {
        stream.readEoln();
        stream.readEof();
        return false;
    }
    if (s != "Possible") {
        stream.quitf(_pe, "incorrect answer format");
    }

    set<pair<int, int>> used;
    for (int i = 0; i < m; i++) {
        int u = stream.readInt(1, n);
        int v = stream.readInt(1, n);
        if (u == v) {
            stream.quitf(_pe, "edges between the same vertex are not allowed");
        }
        if (used.find({v, u}) != used.end()) {
            stream.quitf(_pe, "double edges are not allowed");
        }
        g[u].push_back(v);
        g[v].push_back(u);
        used.emplace(u, v);
        used.emplace(v, u);
    }
    stream.readEoln();
    stream.readEof();

    if (!is_cycle(g) && !is_complete(g) && !is_cm_bipartite(g)) {
        stream.quitf(_wa, "incorrect graph");
    }
    return true;
}

int main(int argc, char *argv[]) {
    registerTestlibCmd(argc, argv);
    n = inf.readInt();
    m = inf.readInt();

    bool expected = readAns(ans);
    bool actual = readAns(ouf);
    if (expected && !actual)
        quitf(_wa, "jury has the answer but participant does not\n");
    else if (expected == actual)
        quitf(_ok, "correct");
    else
        quitf(_fail, ":( participant has found the answer but jury did not\n");
}